@@ -22,11 +22,16 @@ Terms <- function(fit, f, x, trans, alpha, ...) {
     }
   } else {
     V <- vcov(fit)
+    if ('polr' %in% class(fit)) {
+      remove <- grep("|", colnames(V), fixed=TRUE)
+      V <- V[-remove,-remove,drop=FALSE]
+    }
     SE <- sqrt(apply(x$XX * (x$XX %*% V),1,sum))
     yy <- drop(x$XX%*%b[is.finite(b)])
     rr <- visregResid(fit)
-    if (nrow(x$X) != length(rr)) warning("Residuals do not match data; have you changed the original data set?  If so, visreg is probably not displaying the residuals for the data set that was actually used to fit the model.")
+    if (is.null(rr)) rr <- rep(NA, nrow(x$X))
     r <- drop(x$X%*%b[is.finite(b)]) + rr
+    if (nrow(x$X) != length(rr)) warning("Residuals do not match data; have you changed the original data set?  If so, visreg is probably not displaying the residuals for the data set that was actually used to fit the model.")
   }
   if (!all(is.finite(b))) warning("prediction from a rank-deficient fit may be misleading")
   m <- ifelse(identical(class(fit),"lm") || identical(class(fit),"mlm"), qt(1-alpha/2,fit$df.residual), qnorm(1-alpha/2))
