@@ -13,9 +13,12 @@ parseFormula <- function(form) {
     f[i] <- gsub("\\bpoly\\(([^,]+).*\\)", "\\1", f[i])
     f[i] <- gsub("\\bscale\\(([^,]+).*\\)", "\\1", f[i])
     if (substr(f[i], 1, 3) %in% c("te(", "ti(", "lp(") || substr(f[i], 1, 2) %in% c("s(")) {
-      f[i] <- gsub(".*\\(([^\\)]+).*\\)", "\\1", f[i])
-      fi <- unlist(strsplit(f[i], ","))
-      fi <- fi[!grepl("=", fi)]
+      matched <- gregexpr("\\((?>[^()]|(?R))*\\)", f[i], perl = T)
+      fi <- substring(f[i], matched[[1]]+1, matched[[1]] + attr(matched[[1]], "match.length")-2)
+      fi <- gsub("\\([^\\)]+.*\\)", "", fi)
+      fi <- unlist(strsplit(fi, ","))
+      fi <- fi[!grepl("=", fi) | grepl("by\\s*=", fi)]
+      fi <- gsub("by\\s*=", "", fi)
       f[i] <- paste(fi, collapse=" + ")
     }
   }
